@@ -2,11 +2,11 @@
 
 """Glassdoor Python API"""
 
-__version__ = "0.0.1"
+__version__ = "0.0.2"
 __author__ = [
     "Mek <michael.karpeles@gmail.com>"
 ]
 __license__ = "public domain"
 __contributors__ = "see AUTHORS"
 
-from glassdoor.gd import GET, GETjson
+from glassdoor.gd import get, parse
